==> TundereBird-0.24.tar.bz2: TundereBird-0.24/core/Smdn.Net.Pop3.Client/Smdn.Net.Pop3.Protocol.Client/PopCommandSender.cs <==
// 
// Author:
//       smdn <smdn@mail.invisiblefulmoon.net>
// 
// Copyright (c) 2010 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Text;

using Smdn.Formats;
using Smdn.Net.MessageAccessProtocols;

namespace Smdn.Net.Pop3.Protocol.Client {
  public class PopCommandSender : PopSender {
    /*
    public bool CommandContinuing {
      get { return 0 < base.UnsentFragments; }
    }
    */

    public PopCommandSender(LineOrientedBufferedStream stream)
      : base(stream)
    {
    }

    public void Send(PopCommand command)
    {
      ClearUnsent();

      var sb = new StringBuilder();

      if (command.Command != null)
        sb.Append(command.Command);

      foreach (var param in command.Parameters) {
        if (0 < sb.Length)
          sb.Append(Chars.SP);
        sb.Append(param);
      }

      sb.Append(Chars.CRLF);

      Enqueue(NetworkTransferEncoding.Transfer7Bit.GetBytes(sb.ToString()));

      Send();
    }
  }
}

==> TundereBird-0.29.tar.bz2: TundereBird-0.29/core/Smdn.Net.Pop3.Client/Smdn.Net.Pop3.Protocol.Client/PopCommandSender.cs <==
// 
// Author:
//       smdn <smdn@mail.invisiblefulmoon.net>
// 
// Copyright (c) 2010 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Text;

using Smdn.Formats;

namespace Smdn.Net.Pop3.Protocol.Client {
  public class PopCommandSender : PopSender {
    public PopCommandSender(LineOrientedBufferedStream stream)
      : base(stream)
    {
    }

    public void Send(PopCommand command)
    {
      var sb = new StringBuilder();

      if (command.Command != null)
        sb.Append(command.Command);

      foreach (var param in command.Parameters) {
        if (0 < sb.Length)
          sb.Append(Chars.SP);
        sb.Append(param);
      }

      sb.Append(Chars.CRLF);

      Send(NetworkTransferEncoding.Transfer7Bit.GetBytes(sb.ToString()));
    }
  }
}
